Class: Motion::Project::Config

Inherits:
Object
  • Object
show all
Defined in:
lib/motion-cross-platform/stubs.rb,
lib/motion-cross-platform/config.rb

Instance Method Summary collapse

Instance Method Details

#platform(platform_name) ⇒ Object

Allows us to define the config in one file but only execute it when it matches the specified platform.



8
9
10
# File 'lib/motion-cross-platform/config.rb', line 8

def platform(platform_name)
  yield if platform_name.to_sym == template
end